dupin.preprocessing.signal
------------------------------------

.. rubric:: Overview

.. py:currentmodule:: dupin.preprocessing.signal

.. autosummary::
    :nosignatures:

    fft_smoothing
    moving_average

.. rubric:: Details

.. automodule:: dupin.preprocessing.signal
    :synopsis: Functions for transforming feature signals across time.
    :members: fft_smoothing,
        moving_average
